AcceptedMethods enum

Enum with web request methods.

Inheritance
Available extensions

Values

get → const AcceptedMethods
const AcceptedMethods('GET')
post → const AcceptedMethods
const AcceptedMethods('POST')
delete → const AcceptedMethods
const AcceptedMethods('DELETE')
put → const AcceptedMethods
const AcceptedMethods('PUT')
patch → const AcceptedMethods
const AcceptedMethods('PATCH')
const AcceptedMethods('HEAD')
options → const AcceptedMethods
const AcceptedMethods('OPTIONS')
trace → const AcceptedMethods
const AcceptedMethods('TRACE')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AcceptedMethods>
A constant List of the values in this enum, in order of their declaration.