ErrorRouteEmpty class final

Error thrown when Sparky is initialized with an empty set of routes.

At least one route is required for Sparky to function properly. This error indicates that the provided routes list was empty.

Implemented types

Constructors

ErrorRouteEmpty()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited