InternalServerError class

500 Internal Server Error

Inheritance

Constructors

InternalServerError({String message = 'Internal Server Error', Map<String, Object>? details})
const

Properties

details Map<String, Object>?
Optional extra data included in the response body.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
The HTTP status code for this exception.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object>
Returns the JSON body for this exception.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited