close method
Shuts down the test server and closes the HTTP client.
Implementation
Future<void> close() async {
_client.close();
await _server.close();
}
Shuts down the test server and closes the HTTP client.
Future<void> close() async {
_client.close();
await _server.close();
}