RouteWebSocket class final
WebSocket route class
Constructors
- RouteWebSocket(String name, {required MiddlewareWebSocket? middlewareWebSocket})
Properties
-
acceptedMethods
→ List<
AcceptedMethods> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDynamic → bool
-
Whether this route contains dynamic path segments (
:param).latefinalinherited - middleware → Middleware?
-
finalinherited
- middlewareWebSocket → MiddlewareWebSocket?
-
finalinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionCache → int
-
no setterinherited
Methods
-
matchPath(
String path) → Map< String, String> ? -
Tries to match the given
pathagainst this route's pattern. Returns the extracted parameters if matched, ornullif no match.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onUpdate(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited