Scheduler class final
Runtime handle for SchedulerConfig. Internal — managed by Sparky.
Constructors
- Scheduler(SchedulerConfig config)
Properties
- config → SchedulerConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void - Starts all tasks. Idempotent — subsequent calls are no-ops.
-
stop(
) → Future< void> - Stops all tasks. After calling stop, start cannot be used again.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited